@@ -21,7 +21,7 @@
  *          Robert Mibus
  */
 
-/* $Id: backup_conduit.c,v 1.41 2001/10/02 21:11:34 eskil Exp $ */
+/* $Id: backup_conduit.c,v 1.42 2001/10/17 07:53:48 eskil Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -58,6 +58,17 @@ typedef struct file_db {
 	gint entries;
 } file_db;
 
+static char*
+pi_unmktag (long type) {
+	static char tag[5];
+	tag[0] = (type >> 24) & 0xff;
+	tag[1] = (type >> 16) & 0xff;
+	tag[2] = (type >> 8) & 0xff;
+	tag[3] = type & 0xff;
+	tag[4] = 0;
+	return tag;
+}
+
 GnomePilotConduit *conduit_get_gpilot_conduit (guint32 pilotId);
 void conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit);
 
@@ -369,12 +380,13 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 	GList *iterator;
 	int result = 0;
 	ConduitCfg *cfg = (ConduitCfg*)_cfg;
-	int index = 0;
-	int keep_reading = 1;
-	int num_records;
-	PilotRecord remote;	       	      
-	unsigned char *buffer;
+	int index;
+	int keep_reading;
+	int entries;
 	int err;
+	unsigned char *buffer;
+	PilotRecord remote;
+	int wrote;
 
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (dbinfo != NULL, -1);
@@ -451,7 +463,7 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 
 	err = dlp_ReadOpenDBInfo (dbinfo->pilot_socket, 
 				  dbinfo->db_handle,
-				  &num_records);
+				  &entries);
 				    
 	if (err < 0) {
 		g_warning ("error (%s) in reading '%s'", dlp_strerror (err), PI_DBINFO (dbinfo)->name);
@@ -462,6 +474,22 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 	buffer = g_new0 (unsigned char, 0xffff);
 	remote.buffer = buffer;
 
+	{
+		int l;
+		l = dlp_ReadAppBlock (dbinfo->pilot_socket,
+				      dbinfo->db_handle,
+				      0,
+				      buffer,
+				      0xffff);
+		if (l>0) {
+			pi_file_set_app_info (f, buffer, l);
+		}
+	}
+	
+
+	index = 0;
+	keep_reading = 1;
+	wrote = 0;
 	do {
 		unsigned long type;
 		int id;
@@ -474,11 +502,11 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 								 &type,
 								 &id,
 								 &remote.len) >= 0);
-
-			g_message ("appending resource %d (size %d), index %d/%d",
-				   id, remote.len,
-				   index, num_records);
-
+#ifdef DEBUG_REC_IO
+			g_message ("read resource %d, type = %s, size %d, , index %d/%d",
+				   id, pi_unmktag (type), remote.len,
+				   index, entries);
+#endif
 			if (keep_reading) {				
 				err = pi_file_append_resource (f, 
 							       remote.buffer, 
@@ -487,6 +515,13 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 							       id);
 				if (err < 0) {
 					g_warning ("error in writing to file");
+				} else {
+					wrote++;
+#ifdef DEBUG_REC_IO
+					g_message ("write resource %d, type = %s, size %d, index %d/%d",
+						   id, pi_unmktag (type), remote.len,
+						   index, entries);
+#endif
 				}
 			}
 		} else {
@@ -499,9 +534,11 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 							       &remote.flags,
 							       &remote.catID) >= 0);
 
-			g_message ("appending record %d (size %d), index %d/%d",
+#ifdef DEBUG_REC_IO
+			g_message ("read record %d, size %d, index %d/%d",
 				   remote.recID, remote.len,
-				   index, num_records);
+				   index, entries);
+#endif
 
 			if (keep_reading) {
 				err = pi_file_append_record (f, 
@@ -512,15 +549,27 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 							     remote.recID);
 				if (err < 0) {
 					g_warning ("error in writing to file");
+				} else {
+					wrote++;
+#ifdef DEBUG_REC_IO
+					g_message ("write record %d, size %d, index %d/%d",
+						   id, remote.len,
+						   index, entries);
+#endif
 				}
+
 			}
 				
 		}			
 		index++;
 		gnome_pilot_conduit_send_progress (GNOME_PILOT_CONDUIT (conduit),
-						   num_records,
+						   entries,
 						   index);
-	} while (keep_reading && index < num_records);				  
+	} while (keep_reading && index < entries);				  
+
+	g_message ("Wrote %d of %d %s, which is %s",
+		   wrote, entries, PI_DBINFO (dbinfo)->flags & dlpDBFlagResource ? "resources" : "records",
+		   wrote == entries ? "good" : "BAD");
 
 	g_free (buffer);
 		
