@@ -170,7 +170,7 @@ gpilot_hdb_uucp_lock (GPilotDevice *device)
 	char *dev = device->port;
 
 	if (geteuid () != 0) {
-		g_message ("Not root, won't do UUCP lock on %s", device->port);
+		/* g_message ("Not root, won't do UUCP lock on %s", device->port); */
 		return 1;
 	}
 	
@@ -253,7 +253,7 @@ static void
 gpilot_hdb_uucp_unlock (GPilotDevice *device) 
 {
 	if (geteuid () != 0) {
-		g_message ("Not root, won't do UUCP unlock on %s", device->port);
+		/* g_message ("Not root, won't do UUCP unlock on %s", device->port); */
 	}
 
 	if (device->lock_file) {
@@ -290,6 +290,8 @@ gpilot_serial_device_init (GPilotDevice *device)
 					  device->name, device->port,
 					  g_strerror (errno));
 #endif
+		gpilot_hdb_uucp_unlock (device);
+	
 		g_free (device->name);
 		device->name = NULL;
 
@@ -301,8 +303,6 @@ gpilot_serial_device_init (GPilotDevice *device)
 
 		device->io = NULL;
 
-		gpilot_hdb_uucp_unlock (device);
-	
 		return -1;
 	}
 	device->io = g_io_channel_unix_new (device->fd);
