@@ -135,25 +135,25 @@ static gint
 find_matching_conduit_compare_func_name (GnomePilotConduit *conduit,
 					gchar *name) 
 {
-  if (GNOME_IS_PILOT_CONDUIT_STANDARD (conduit)) {
-    if (strcmp (gnome_pilot_conduit_standard_get_db_name (GNOME_PILOT_CONDUIT_STANDARD (conduit)),
-	      name)==0) {
-      return 0;
-    }
-  }
-  return -1;
+	if (GNOME_IS_PILOT_CONDUIT (conduit)) {
+		if (strcmp (gnome_pilot_conduit_get_name (conduit),
+			    name)==0) {
+			return 0;
+		}
+	}
+	return -1;
 }
 
 static GnomePilotConduit*
 find_matching_conduit_name (GList *conlist, gchar *name)
 {
-  GList *elem;
-  elem=g_list_find_custom (conlist, name,
-			  (GCompareFunc)find_matching_conduit_compare_func_name);
-  if (elem)
-    return GNOME_PILOT_CONDUIT (elem->data);
-  else
-    return NULL;
+	GList *elem;
+	elem=g_list_find_custom (conlist, name,
+				 (GCompareFunc)find_matching_conduit_compare_func_name);
+	if (elem)
+		return GNOME_PILOT_CONDUIT (elem->data);
+	else
+		return NULL;
 }
 
 /**************************************************************************/
@@ -335,14 +335,15 @@ iterate_dbs (gint pfd,
 		if (0) {
 			char creat[4];
 			memcpy (creat, (void*)&PI_DBINFO (dbinfo)->creator, 4);
-			g_message ("DB: %20s: Exclude=%3s, Backup=%3s Flags=0x%8.8x Creator=0x%lx (%c%c%c%c) Backupdate = %ld modifydate = %ld",
+			g_message ("DB: %20s: Exclude=%3s, Backup=%3s Flags=0x%8.8x Creator=0x%lx (%c%c%c%c) Backupdate = %ld modifydate = %ld, %d/%d",
 				   PI_DBINFO (dbinfo)->name,
 				   (PI_DBINFO (dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)?"yes":"no",
 				   (PI_DBINFO (dbinfo)->flags & dlpDBFlagBackup)?"yes":"no",
 				   PI_DBINFO (dbinfo)->flags,
 				   PI_DBINFO (dbinfo)->creator, creat[3], creat[2], creat[1], creat[0],
 				   PI_DBINFO (dbinfo)->backupDate,
-				   PI_DBINFO (dbinfo)->modifyDate);
+				   PI_DBINFO (dbinfo)->modifyDate,
+				   index, g_list_length (dbs));
 		}
 
 		/* check if the base is marked as being excluded from sync */
@@ -354,8 +355,6 @@ iterate_dbs (gint pfd,
 
 			conduit = find_matching_conduit (conlist, dbinfo);
 
-			orbed_notify_overall_progress (pilot_info->name, index, g_list_length (dbs)); 
-
 			if (conduit) {
 				/* Now call the iter method on the conduit, after setting up
 				   the signals. The signals aren't set before, since we 
@@ -366,9 +365,16 @@ iterate_dbs (gint pfd,
 				set_callbacks (FALSE, GNOME_PILOT_CONDUIT (conduit), pilot_info->name);
 			}
 
-			g_list_foreach (bconlist,
-					(GFunc) backup_foreach,
-					dbinfo);
+			orbed_notify_overall_progress (pilot_info->name, index, g_list_length (dbs)); 
+
+			/*
+			  It seems pretty erratic which has this and which hasn't,
+			  so I'm not doing this check.
+			if (PI_DBINFO (dbinfo)->miscFlags & dlpDBFlagBackup)
+			*/
+				g_list_foreach (bconlist,
+						(GFunc) backup_foreach,
+						dbinfo);
 
 		} else {
 			LOG ("Base %s is to be ignored by sync", PI_DBINFO (dbinfo)->name);
@@ -538,13 +544,14 @@ conduit_sync_default (GnomePilotConduitStandard *conduit, GnomePilotDBInfo *dbin
 static void
 install_db_foreach (GPilotRequest *req, GnomePilotInstallCarrier *carrier) {
 	gchar *pilot_name;
+	int err;
 
 	pilot_name = pilot_name_from_id (carrier->pu->userID, carrier->context);
 	set_callbacks (TRUE, carrier->conduit, pilot_name);
-	gnome_pilot_conduit_file_install_db (GNOME_PILOT_CONDUIT_FILE (carrier->conduit),
-					     carrier->pilot_socket,
-					     req->parameters.install.filename,
-					     TRUE);
+	err = gnome_pilot_conduit_file_install_db (GNOME_PILOT_CONDUIT_FILE (carrier->conduit),
+						   carrier->pilot_socket,
+						   req->parameters.install.filename,
+						   TRUE);
 	set_callbacks (FALSE, carrier->conduit, pilot_name);
 
 	g_free (pilot_name);
@@ -697,6 +704,8 @@ gpilot_load_conduits (GPilotContext *context,
 		g_free (conduit_name[i]);
 	}
 	g_free (conduit_name);
+	g_message ("Instantiated %d backup conduits, %d file conduits, %d other conduits",
+		   g_list_length (*blist), g_list_length (*flist), g_list_length (*clist));
 }
 
 void
@@ -786,12 +795,12 @@ run_conduit_sync_foreach (GPilotRequest *req,
 	conduit = NULL;
 
 	conduit = find_matching_conduit_name (carrier->conduit_list,
-					     req->parameters.conduit.name);
+					      req->parameters.conduit.name);
 	if (conduit==NULL) {
 		/* FIXME: remove the bloody request, or the user will get this
 		   message every time */
-		g_error (_("Conduit %s requested, but not found"),
-			req->parameters.conduit.name);
+		g_warning (_("Conduit %s requested, but not found"),
+			   req->parameters.conduit.name);
 	} else {
 		if (GNOME_IS_PILOT_CONDUIT_BACKUP (conduit)) {
 			blist = g_list_append (blist, conduit);
@@ -805,9 +814,8 @@ run_conduit_sync_foreach (GPilotRequest *req,
 		}
 
 		if (flist) {
-			g_list_foreach (flist,(GFunc)install_foreach,&carrier);
+			g_list_foreach (flist, (GFunc)install_foreach, carrier);
 		} else {
-	    
 			err= iterate_dbs (carrier->pilot_socket,
 					  carrier->syncstamp,
 					  carrier->pu,
